
# Slot: source web page




URI: [biolink:source_web_page](https://w3id.org/biolink/vocab/source_web_page)

## Domain and Range

[DataSetSummary](DataSetSummary.md) ->  <sub>OPT</sub> [String](String.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [DataSetSummary](DataSetSummary.md)
